import os
import protobix
import logging

from .toolbox import AppError
from zabbixactivechecks import ItemList


class Zabbix(object):
    def __init__(self):
        self.logProtobix = logging.getLogger('Protobix')
        # self.logProtobix.setLevel(logging.INFO)
        self.zbx_config = protobix.ZabbixAgentConfig()
        #     logger=self.logProtobix
        # )
        self.zbx_config.server_active = os.getenv('ZBX_SERVER_HOST')
        self.zbx_config.server_port = int(os.getenv('ZBX_SERVER_PORT'))
        self.zbx_config.timeout = 10

        self.zbx_datacontainer = None

    def initSender(self, dataType='items'):
        self.zbx_config.data_type = dataType
        self.zbx_datacontainer = protobix.DataContainer(config=self.zbx_config)
        return self.zbx_datacontainer

    def getItemList(self, host, hostMetadata=None):
        try:
            list = ItemList(host=host)
            response = list.get(
                server=self.zbx_config.server_active,
                port=self.zbx_config.server_port,
                hostMetadata=hostMetadata
            )
            return response.data
        except Exception as e:
            raise AppError(str(e))



import os
import docker

from .toolbox import AppError
from dockermetrics import containerMetrics


class dockerData(object):
    def __init__(self,
                 clusterLabel=os.getenv(
                     'CLUSTER_LABEL',
                     'com.amazonaws.ecs.cluster'
                 ),
                 serviceLabel=os.getenv(
                     'SERVICE_LABEL',
                     'com.amazonaws.ecs.task-definition-family'
                 )):
        self.clusterLabel = clusterLabel
        self.serviceLabel = serviceLabel

        self.docker = docker.from_env()
        self.containers = {}
        self.discoveryData = []

    def discover_containers(self):
        for container in self.docker.containers.list():
            self.discoveryData.append({
                '{#CONTAINER_NAME}': container.name,
                '{#CONTAINER_ID}': container.id,
                '{#CONTAINER_STATUS}': container.status,
                '{#CONTAINER_CLUSTER}':
                    container.labels.get(self.clusterLabel),
                '{#CONTAINER_SERVICE}':
                    container.labels.get(self.serviceLabel)
            })
            self.containers[container.id] = {
                'name': container.name,
                'short_id': container.short_id,
                'status': container.status,
                'labels': container.labels
            }

    def metrics(self, containerId):
        try:
            return containerMetrics(
                containerId=containerId,
                sysfs=os.getenv('CGROUPS_DIR', '/cgroupsfs')
            )
        except Exception as e:
            raise AppError(str(e))



#!/usr/bin/env python

from setuptools import setup

setup(
    # Application name:
    name="zabbix-docker-agent",

    # Version number (initial):
    version="0.0.6",

    # Application author details:
    author="Alen Komic",
    author_email="akomic@gmail.com",

    # Packages
    packages=["ZabbixDockerAgent"],

    # Scripts
    scripts=['zabbixAgentd'],

    # Include additional files into the package
    include_package_data=True,

    # Details
    url="https://github.com/akomic/zabbix-docker-agent",

    #
    # license="LICENSE.txt",
    description="Zabbix Docker Agent for collecting dynamic" +
                " container statistics",

    long_description=open("README.txt").read(),

    keywords=['docker', 'monitoring', 'metrics', 'zabbix'],

    # Dependent packages (distributions)
    install_requires=[
        'docker==2.4.0', 'docker-metrics==0.0.3',
        'protobix==1.0.0', 'zabbixactivechecks==0.0.5'
    ],
)
